@@ -1037,7 +1037,7 @@ avl_verify_rank (avl_node * node)
       num_right = avl_verify_rank (node->right);
     }
     if (AVL_GET_RANK (node) != num_left + 1) {
-      fprintf (stderr, "invalid rank at node %ld\n", (long) node->key);
+      fprintf (stderr, "invalid rank at node %p\n", node->key);
       exit (1);
     }
     return (num_left + num_right + 1);
