@@ -47,8 +47,8 @@ P32.init = function() {
     components.Component.prototype.shiftChannel = true;
     components.Button.prototype.sendShifted = true;
 
-    if (engine.getValue("[Master]", "num_samplers") < 32) {
-        engine.setValue("[Master]", "num_samplers", 32);
+    if (engine.getValue("[App]", "num_samplers") < 32) {
+        engine.setValue("[App]", "num_samplers", 32);
     }
 
     P32.leftDeck = new P32.Deck([1, 3], 1);
@@ -143,7 +143,7 @@ P32.slipButton = new components.Button({
     connect: function() {
         for (var d = 1; d <= 4; d++) {
             this.connections.push(
-                engine.connectControl("[Channel" + d + "]", "slip_enabled", this.output)
+                engine.connectControl("[Channel" + d + "]", "slip_enabled", this.output.bind(this))
             );
         }
     },
@@ -224,9 +224,9 @@ P32.Deck = function(deckNumbers, channel) {
             };
         },
         connect: function() {
-            this.connections[0] = engine.connectControl(this.group, "beatloop_size", this.output);
+            this.connections[0] = engine.connectControl(this.group, "beatloop_size", this.output.bind(this));
             if (loopEnabledDot) {
-                this.connections[1] = engine.connectControl(this.group, "loop_enabled", this.output);
+                this.connections[1] = engine.connectControl(this.group, "loop_enabled", this.output.bind(this));
             }
         },
         output: function(_value, _group, _control) {
