@@ -37,9 +37,7 @@ class ControlDoublePrivate : public QObject {
     // Used to implement control persistence. All controls that are marked
     // "persist in user config" get and set their value on creation/deletion
     // using this UserSettings.
-    static void setUserConfig(UserSettingsPointer pConfig) {
-        s_pUserConfig = pConfig;
-    }
+    static void setUserConfig(const UserSettingsPointer& pConfig);
 
     // Adds a ConfigKey for 'alias' to the control for 'key'. Can be used for
     // supporting a legacy / deprecated control. The 'key' control must exist
@@ -57,17 +55,14 @@ class ControlDoublePrivate : public QObject {
             bool bTrack = false,
             bool bPersist = false,
             double defaultValue = 0.0);
+    static QSharedPointer<ControlDoublePrivate> getDefaultControl();
 
     // Returns a list of all existing instances.
     static QList<QSharedPointer<ControlDoublePrivate>> getAllInstances();
     // Clears all existing instances and returns them as a list.
     static QList<QSharedPointer<ControlDoublePrivate>> takeAllInstances();
 
-    static QHash<ConfigKey, ConfigKey> getControlAliases() {
-        MMutexLocker locker(&s_qCOHashMutex);
-        // lock thread-unsafe copy constructors of QHash
-        return s_qCOAliasHash;
-    }
+    static QHash<ConfigKey, ConfigKey> getControlAliases();
 
     const QString& name() const {
         return m_name;
@@ -85,6 +80,14 @@ class ControlDoublePrivate : public QObject {
         m_description = description;
     }
 
+    void setKbdRepeatable(bool enable) {
+        m_kbdRepeatable = enable;
+    }
+
+    bool getKbdRepeatable() const {
+        return m_kbdRepeatable;
+    }
+
     // Sets the control value.
     void set(double value, QObject* pSender);
     // directly sets the control value. Must be used from and only from the
@@ -134,7 +137,7 @@ class ControlDoublePrivate : public QObject {
     }
     void deleteCreatorCO();
 
-    ConfigKey getKey() {
+    const ConfigKey& getKey() {
         return m_key;
     }
 
@@ -159,6 +162,9 @@ class ControlDoublePrivate : public QObject {
     void valueChanged(double value, QObject* pSender);
     void valueChangeRequest(double value);
 
+  protected:
+    ControlDoublePrivate();
+
   private:
     ControlDoublePrivate(
             const ConfigKey& key,
@@ -173,7 +179,7 @@ class ControlDoublePrivate : public QObject {
     ControlDoublePrivate& operator=(const ControlDoublePrivate&) = delete;
 
     void initialize(double defaultValue);
-    void setInner(double value, QObject* pSender);
+    virtual void setInner(double value, QObject* pSender);
 
     const ConfigKey m_key;
 
@@ -200,28 +206,32 @@ class ControlDoublePrivate : public QObject {
     // User-visible, i18n description for what the control does.
     QString m_description;
 
+    // If true, this control will be issued repeatedly if the keyboard key is held.
+    bool m_kbdRepeatable;
+
     // The control value.
     ControlValueAtomic<double> m_value;
     // The default control value.
     ControlValueAtomic<double> m_defaultValue;
 
     QSharedPointer<ControlNumericBehavior> m_pBehavior;
+};
 
-    // Hack to implement persistent controls. This is a pointer to the current
-    // user configuration object (if one exists). In general, we do not want the
-    // user configuration to be a singleton -- objects that need access to it
-    // should be passed it explicitly. However, the Control system is so
-    // pervasive that updating every control creation to include the
-    // configuration object would be arduous.
-    static UserSettingsPointer s_pUserConfig;
+/// The constant ControlDoublePrivate version is used as dummy for default
+/// constructed control objects
+class ControlDoublePrivateConst : public ControlDoublePrivate {
+    Q_OBJECT
+  public:
+    ~ControlDoublePrivateConst() override = default;
 
-    // Hash of ControlDoublePrivate instantiations.
-    static QHash<ConfigKey, QWeakPointer<ControlDoublePrivate>> s_qCOHash;
+    void setInner(double value, QObject* pSender) override {
+        Q_UNUSED(value)
+        Q_UNUSED(pSender)
+        DEBUG_ASSERT(!"Trying to modify a default constructed (const) control object");
+    };
 
-    // Hash of aliases between ConfigKeys. Solely used for looking up the first
-    // alias associated with a key.
-    static QHash<ConfigKey, ConfigKey> s_qCOAliasHash;
+  protected:
+    ControlDoublePrivateConst() = default;
 
-    // Mutex guarding access to s_qCOHash and s_qCOAliasHash.
-    static MMutex s_qCOHashMutex;
+    friend ControlDoublePrivate;
 };
