@@ -1,6 +1,7 @@
 #pragma once
 
 #include "controllers/midi/midienumerator.h"
+#include "preferences/usersettings.h"
 
 // Handles discovery and enumeration of DJ controllers that appear under the
 // HSS1394 cross-platform API.
@@ -10,7 +11,7 @@ class Hss1394Enumerator : public MidiEnumerator {
     explicit Hss1394Enumerator(UserSettingsPointer pConfig);
     virtual ~Hss1394Enumerator();
 
-    QList<Controller*> queryDevices();
+    QList<Controller*> queryDevices() override;
 
   private:
     UserSettingsPointer m_pConfig;
