@@ -144,7 +144,14 @@ DlgAbout::DlgAbout()
             << "Hetarth Jodha"
             << "Harsh Barhate"
             << "Nikhil Bisht"
-            << "Jan Claußen";
+            << "Jan Claußen"
+            << "Nisarg Shah"
+            << "Manish Sehrawat"
+            << "xuijuthub"
+            << "Nicolay Leiva"
+            << "Didier Malenfant"
+            << "Rene E"
+            << "Owen Turnbull";
 
     QStringList specialThanks;
     specialThanks
