@@ -1,9 +1,8 @@
 #pragma once
 
-#include <QWidget>
+#include <QDialog>
 
 #include "dialog/ui_dlgaboutdlg.h"
-#include "preferences/usersettings.h"
 
 class DlgAbout : public QDialog, public Ui::DlgAboutDlg {
     Q_OBJECT
