@@ -1,5 +1,6 @@
 #include "engine/positionscratchcontroller.h"
 
+#include "audio/frame.h"
 #include "control/controlobject.h"
 #include "control/controlproxy.h"
 #include "engine/bufferscalers/enginebufferscale.h" // for MIN_SEEK_SPEED
@@ -95,9 +96,7 @@ PositionScratchController::PositionScratchController(const QString& group)
           m_isScratching(false),
           m_inertiaEnabled(false),
           m_prevSamplePos(0),
-          // TODO we might as well use FramePos in order to use more convenient
-          // mixxx::audio::kInvalidFramePos, then convert to sample pos on the fly
-          m_seekSamplePos(std::numeric_limits<double>::quiet_NaN()),
+          m_seekFramePos(mixxx::audio::kInvalidFramePos),
           m_samplePosDeltaSum(0),
           m_scratchTargetDelta(0),
           m_scratchStartPos(0),
@@ -314,18 +313,31 @@ void PositionScratchController::process(double currentSamplePos,
         // qDebug() << "scratchEnable()" << currentSamplePos;
     }
 
-    if (!util_isnan(m_seekSamplePos)) {
-        // We need to transpose all buffers to compensate the seek
-        // in a way that the next process call does not even notice anything
-        currentSamplePos = m_seekSamplePos;
-        m_seekSamplePos = std::numeric_limits<double>::quiet_NaN();
+    if (m_seekFramePos.isValid()) {
+        // This is true when the engine seeked, so we now need to adopt the new
+        // position, ie. transpose all buffers to compensate the seek
+        // in a way that the next process call does not even notice anything.
+        // Else the PID controller will give us insane high scratch rates
+        // (insane scratch sounds) and the play position will be horribly off.
+        // See https://github.com/mixxxdj/mixxx/pull/14357
+        currentSamplePos = m_seekFramePos.toEngineSamplePos();
+        m_seekFramePos = mixxx::audio::kInvalidFramePos;
     }
     m_prevSamplePos = currentSamplePos;
 }
 
 void PositionScratchController::notifySeek(mixxx::audio::FramePos position) {
-    const double newPos = position.toEngineSamplePos();
     // Scratching continues after seek due to calculating the relative
     // distance traveled in m_samplePosDeltaSum
-    m_seekSamplePos = newPos;
+    m_seekFramePos = position;
+}
+
+void PositionScratchController::reset() {
+    // Resets the scratch state to avoid engine freeze due to insanley high rate
+    // reported on track load while scratching.
+    // https://github.com/mixxxdj/mixxx/issues/15082
+    m_pScratchEnable->set(0.0);
+    m_isScratching = false;
+    m_inertiaEnabled = false;
+    m_rate = 0;
 }
