@@ -32,6 +32,10 @@ class AutoDJFeature : public LibraryFeature {
 
     QVariant title() override;
 
+    void clear() override;
+    void paste() override;
+    void deleteItem(const QModelIndex& index) override;
+
     bool dropAccept(const QList<QUrl>& urls, QObject* pSource) override;
     bool dragMoveAccept(const QUrl& url) override;
 
@@ -48,6 +52,7 @@ class AutoDJFeature : public LibraryFeature {
   public slots:
     void activate() override;
 
+    void onRightClick(const QPoint& globalPos) override;
     // Temporary, until WCrateTableView can be written.
     void onRightClickChild(const QPoint& globalPos, const QModelIndex& index) override;
 
@@ -63,6 +68,7 @@ class AutoDJFeature : public LibraryFeature {
 
     // Initialize the list of crates loaded into the auto-DJ queue.
     void constructCrateChildModel();
+    void removeCrateFromAutoDj(CrateId crateId = CrateId());
 
     // The "Crates" tree-item under the "Auto DJ" tree-item.
     TreeItem* m_pCratesTreeItem;
@@ -75,24 +81,22 @@ class AutoDJFeature : public LibraryFeature {
     // How we access the auto-DJ-crates database.
     AutoDJCratesDAO m_autoDjCratesDao;
 
+    parented_ptr<QAction> m_pClearQueueAction;
     // A context-menu item that allows crates to be removed from the
     // auto-DJ list.
-    QAction* m_pRemoveCrateFromAutoDj;
+    parented_ptr<QAction> m_pRemoveCrateFromAutoDjAction;
 
     QPointer<WLibrarySidebar> m_pSidebarWidget;
 
   private slots:
+    void slotClearQueue();
     // Add a crate to the auto-DJ queue.
     void slotAddCrateToAutoDj(CrateId crateId);
-
     // Implements the context-menu item.
     void slotRemoveCrateFromAutoDj();
-
     void slotCrateChanged(CrateId crateId);
-
     // Adds a random track from all loaded crates to the auto-DJ queue.
     void slotAddRandomTrack();
-
     // Adds a random track from the queue upon hitting minimum number
     // of tracks in the playlist
     void slotRandomQueue(int numTracksToAdd);
