@@ -29,15 +29,17 @@ class BaseExternalLibraryFeature : public LibraryFeature {
   protected:
     // Must be re-implemented by external Libraries copied to Mixxx DB
     virtual std::unique_ptr<BaseSqlTableModel> createPlaylistModelForPlaylist(
-            const QString& playlist);
+            const QVariant& data);
     // Must be implemented by external Libraries not copied to Mixxx DB
-    virtual void appendTrackIdsFromRightClickIndex(QList<TrackId>* trackIds, QString* pPlaylist);
+    virtual void appendTrackIdsFromRightClickIndex(QList<TrackId>* trackIds,
+            QString* pPlaylist);
 
   private slots:
     void slotAddToAutoDJ();
     void slotAddToAutoDJTop();
     void slotAddToAutoDJReplace();
     void slotImportAsMixxxPlaylist();
+    void slotImportAsMixxxCrate();
 
   protected:
     QModelIndex lastRightClickedIndex() const {
@@ -60,6 +62,7 @@ class BaseExternalLibraryFeature : public LibraryFeature {
     parented_ptr<QAction> m_pAddToAutoDJTopAction;
     parented_ptr<QAction> m_pAddToAutoDJReplaceAction;
     parented_ptr<QAction> m_pImportAsMixxxPlaylistAction;
+    parented_ptr<QAction> m_pImportAsMixxxCrateAction;
 
     QPointer<WLibrarySidebar> m_pSidebarWidget;
 };
