@@ -1,16 +1,12 @@
 #pragma once
 
-#include <QtSql>
-#include <QItemDelegate>
-#include <QString>
 #include <QObject>
-#include <QModelIndex>
+#include <QString>
 
-#include "library/trackmodel.h"
 #include "library/basesqltablemodel.h"
-#include "library/librarytablemodel.h"
-#include "library/dao/playlistdao.h"
-#include "library/dao/trackdao.h"
+#include "library/trackmodel.h"
+
+class QModelIndex;
 
 class BaseExternalPlaylistModel : public BaseSqlTableModel {
     Q_OBJECT
@@ -22,12 +18,14 @@ class BaseExternalPlaylistModel : public BaseSqlTableModel {
     ~BaseExternalPlaylistModel() override;
 
     void setPlaylist(const QString& path_name);
+    void setPlaylistById(int playlistId);
 
     TrackPointer getTrack(const QModelIndex& index) const override;
     TrackId getTrackId(const QModelIndex& index) const override;
     bool isColumnInternal(int column) override;
-    Qt::ItemFlags flags(const QModelIndex &index) const override;
-    CapabilitiesFlags getCapabilities() const override;
+    Qt::ItemFlags flags(const QModelIndex& index) const override;
+    Capabilities getCapabilities() const override;
+    QString modelKey(bool noSearch) const override;
 
   private:
     TrackId doGetTrackId(const TrackPointer& pTrack) const override;
@@ -35,4 +33,6 @@ class BaseExternalPlaylistModel : public BaseSqlTableModel {
     QString m_playlistsTable;
     QString m_playlistTracksTable;
     QSharedPointer<BaseTrackCache> m_trackSource;
+    int m_currentPlaylistId;
+    QHash<int, QString> m_searchTexts;
 };
