@@ -1411,10 +1411,13 @@ void RekordboxFeature::htmlLinkClicked(const QUrl& link) {
 }
 
 std::unique_ptr<BaseSqlTableModel>
-RekordboxFeature::createPlaylistModelForPlaylist(const QString& playlist) {
+RekordboxFeature::createPlaylistModelForPlaylist(const QVariant& data) {
     auto pModel = std::make_unique<RekordboxPlaylistModel>(
             this, m_pLibrary->trackCollectionManager(), m_trackSource);
-    pModel->setPlaylist(playlist);
+    VERIFY_OR_DEBUG_ASSERT(data.toList().size() > 0) {
+        return {};
+    }
+    pModel->setPlaylist(data.toList()[0].toString());
     return pModel;
 }
 
