@@ -97,14 +97,14 @@ RhythmboxFeature::~RhythmboxFeature() {
 }
 
 std::unique_ptr<BaseSqlTableModel>
-RhythmboxFeature::createPlaylistModelForPlaylist(const QString& playlist) {
+RhythmboxFeature::createPlaylistModelForPlaylist(const QVariant& data) {
     auto pModel = std::make_unique<BaseExternalPlaylistModel>(this,
             m_pLibrary->trackCollectionManager(),
             "mixxx.db.model.rhythmbox_playlist",
             "rhythmbox_playlists",
             "rhythmbox_playlist_tracks",
             m_trackSource);
-    pModel->setPlaylist(playlist);
+    pModel->setPlaylist(data.toString());
     return pModel;
 }
 
