@@ -1,11 +1,11 @@
 #pragma once
 
-#include <QThread>
 #include <QWidget>
-#include <QString>
 
 #include "util/performancetimer.h"
 
+class QString;
+
 class LibraryScannerDlg : public QWidget {
     Q_OBJECT
   public:
