@@ -1,6 +1,7 @@
 #include "library/searchqueryparser.h"
 
 #include <QRegularExpression>
+#include <memory>
 #include <utility>
 
 #include "library/searchquery.h"
@@ -56,9 +57,15 @@ std::pair<QString, Quoted> consumeQuotedArgument(QString argument,
 
 constexpr char kNegatePrefix[] = "-";
 constexpr char kFuzzyPrefix[] = "~";
+
 // see https://stackoverflow.com/questions/1310473/regex-matching-spaces-but-not-in-strings
+#define QUOTED_STRING_LOOKAHEAD "(?=[^\"]*(\"[^\"]*\"[^\"]*)*$)"
+
 const QRegularExpression kSplitIntoWordsRegexp = QRegularExpression(
-        QStringLiteral(" (?=[^\"]*(\"[^\"]*\"[^\"]*)*$)"));
+        QStringLiteral(" " QUOTED_STRING_LOOKAHEAD));
+
+const QRegularExpression kSplitOnOrOperatorRegexp = QRegularExpression(
+        QStringLiteral("(?:\\||\\bOR\\b)" QUOTED_STRING_LOOKAHEAD));
 
 SearchQueryParser::SearchQueryParser(TrackCollection* pTrackCollection, QStringList searchColumns)
         : m_pTrackCollection(pTrackCollection),
@@ -74,14 +81,16 @@ SearchQueryParser::SearchQueryParser(TrackCollection* pTrackCollection, QStringL
                   << "grouping"
                   << "comment"
                   << "location"
-                  << "crate";
+                  << "crate"
+                  << "type";
     m_numericFilters << "track"
-                     << "bpm"
                      << "played"
                      << "rating"
-                     << "bitrate";
+                     << "bitrate"
+                     << "id";
     m_specialFilters << "year"
                      << "key"
+                     << "bpm"
                      << "duration"
                      << "added"
                      << "dateadded"
@@ -107,13 +116,10 @@ SearchQueryParser::SearchQueryParser(TrackCollection* pTrackCollection, QStringL
     m_fieldToSqlColumns["lastplayed"] << "last_played_at";
     m_fieldToSqlColumns["rating"] << "rating";
     m_fieldToSqlColumns["location"] << "location";
+    m_fieldToSqlColumns["type"] << "filetype";
     m_fieldToSqlColumns["datetime_added"] << "datetime_added";
+    m_fieldToSqlColumns["id"] << "id";
 
-    m_allFilters.append(m_textFilters);
-    m_allFilters.append(m_numericFilters);
-    m_allFilters.append(m_specialFilters);
-
-    m_fuzzyMatcher = QRegularExpression(QString("^~(%1)$").arg(m_allFilters.join("|")));
     m_textFilterMatcher = QRegularExpression(QString("^-?(%1):(.*)$").arg(m_textFilters.join("|")));
     m_numericFilterMatcher = QRegularExpression(
             QString("^-?(%1):(.*)$").arg(m_numericFilters.join("|")));
@@ -135,7 +141,8 @@ void SearchQueryParser::setSearchColumns(QStringList searchColumns) {
 }
 
 SearchQueryParser::TextArgumentResult SearchQueryParser::getTextArgument(QString argument,
-        QStringList* tokens) const {
+        QStringList* tokens,
+        bool removeLeadingEqualsSign) const {
     // If the argument is empty, assume the user placed a space after an
     // advanced search command. Consume another token and treat that as the
     // argument.
@@ -146,7 +153,7 @@ SearchQueryParser::TextArgumentResult SearchQueryParser::getTextArgument(QString
         }
     }
     StringMatch mode = StringMatch::Contains;
-    if (argument.startsWith("=")) {
+    if (removeLeadingEqualsSign && argument.startsWith("=")) {
         // strip the '=' from the argument
         argument = argument.mid(1);
         mode = StringMatch::Equals;
@@ -172,13 +179,10 @@ void SearchQueryParser::parseTokens(QStringList tokens,
         bool negate = token.startsWith(kNegatePrefix);
         std::unique_ptr<QueryNode> pNode;
 
-        const QRegularExpressionMatch fuzzyMatch = m_fuzzyMatcher.match(token);
         const QRegularExpressionMatch textFilterMatch = m_textFilterMatcher.match(token);
         const QRegularExpressionMatch numericFilterMatch = m_numericFilterMatcher.match(token);
         const QRegularExpressionMatch specialFilterMatch = m_specialFilterMatcher.match(token);
-        if (fuzzyMatch.hasMatch()) {
-            // TODO(XXX): implement this feature.
-        } else if (textFilterMatch.hasMatch()) {
+        if (textFilterMatch.hasMatch()) {
             QString field = textFilterMatch.captured(1);
             auto [argument, matchMode] = getTextArgument(textFilterMatch.captured(2), &tokens);
 
@@ -220,10 +224,11 @@ void SearchQueryParser::parseTokens(QStringList tokens,
             }
         } else if (specialFilterMatch.hasMatch()) {
             bool fuzzy = token.startsWith(kFuzzyPrefix);
+            bool negate = token.startsWith(kNegatePrefix);
             QString field = specialFilterMatch.captured(1);
-            QString argument = getTextArgument(
-                    specialFilterMatch.captured(2), &tokens)
-                                       .argument;
+            auto [argument, matchMode] = getTextArgument(
+                    specialFilterMatch.captured(2), &tokens);
+
             if (!argument.isEmpty()) {
                 if (field == "key") {
                     mixxx::track::io::key::ChromaticKey key =
@@ -250,8 +255,13 @@ void SearchQueryParser::parseTokens(QStringList tokens,
                         field == "added" ||
                         field == "dateadded") {
                     field = "datetime_added";
-                    pNode = std::make_unique<TextFilterNode>(
-                        m_pTrackCollection->database(), m_fieldToSqlColumns[field], argument);
+                    pNode = std::make_unique<DateAddedFilterNode>(argument);
+                } else if (field == "bpm") {
+                    if (matchMode == StringMatch::Equals) {
+                        // restore = operator removed by getTextArgument()
+                        argument.prepend('=');
+                    }
+                    pNode = std::make_unique<BpmFilterNode>(argument, fuzzy, negate);
                 }
             }
         } else {
@@ -287,6 +297,33 @@ void SearchQueryParser::parseTokens(QStringList tokens,
     }
 }
 
+std::unique_ptr<AndNode> SearchQueryParser::parseAndNode(const QString& query) const {
+    auto pQuery = std::make_unique<AndNode>();
+
+    QStringList tokens = query.split(" ");
+    parseTokens(std::move(tokens), pQuery.get());
+
+    return pQuery;
+}
+
+std::unique_ptr<OrNode> SearchQueryParser::parseOrNode(const QString& query) const {
+    auto pQuery = std::make_unique<OrNode>();
+
+    const QStringList rawAndNodes = query.split(kSplitOnOrOperatorRegexp,
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+            Qt::SkipEmptyParts);
+#else
+            QString::SkipEmptyParts);
+#endif
+    for (const QString& rawAndNode : rawAndNodes) {
+        if (!rawAndNode.isEmpty()) {
+            pQuery->addNode(parseAndNode(rawAndNode));
+        }
+    }
+
+    return pQuery;
+}
+
 std::unique_ptr<QueryNode> SearchQueryParser::parseQuery(
         const QString& query,
         const QString& extraFilter) const {
@@ -297,8 +334,7 @@ std::unique_ptr<QueryNode> SearchQueryParser::parseQuery(
     }
 
     if (!query.isEmpty()) {
-        QStringList tokens = query.split(" ");
-        parseTokens(tokens, pQuery.get());
+        pQuery->addNode(parseOrNode(query));
     }
 
     return pQuery;
