@@ -1,13 +1,13 @@
 #pragma once
 
 #include <QMetaMethod>
-#include <QNetworkAccessManager>
-#include <QNetworkReply>
 #include <QUrl>
 
 #include "util/assert.h"
 #include "util/qt.h"
 
+class QNetworkAccessManager;
+
 namespace mixxx {
 
 namespace network {
