@@ -44,23 +44,30 @@ WaveformWidgetType::Type upgradeToAllShaders(WaveformWidgetType::Type waveformTy
     case WWT::AllShaderRGBWaveform:
     case WWT::AllShaderLRRGBWaveform:
     case WWT::AllShaderFilteredWaveform:
+    case WWT::AllShaderRGBStackedWaveform:
     case WWT::AllShaderSimpleWaveform:
     case WWT::AllShaderHSVWaveform:
+    case WWT::AllShaderTexturedFiltered:
+    case WWT::AllShaderTexturedRGB:
+    case WWT::AllShaderTexturedStacked:
     case WWT::Count_WaveformwidgetType:
         return waveformType;
     case WWT::QtSimpleWaveform:
     case WWT::GLSimpleWaveform:
         return WaveformWidgetType::AllShaderSimpleWaveform;
     case WWT::GLFilteredWaveform:
-    case WWT::GLSLFilteredWaveform:
         return WaveformWidgetType::AllShaderFilteredWaveform;
+    case WWT::GLSLFilteredWaveform:
+        return WaveformWidgetType::AllShaderTexturedFiltered;
     case WWT::QtWaveform:
     case WWT::RGBWaveform:
     case WWT::GLRGBWaveform:
-    case WWT::GLSLRGBWaveform:
     case WWT::QtRGBWaveform:
-    case WWT::GLSLRGBStackedWaveform:
         return WWT::AllShaderRGBWaveform;
+    case WWT::GLSLRGBWaveform:
+        return WWT::AllShaderTexturedRGB;
+    case WWT::GLSLRGBStackedWaveform:
+        return WWT::AllShaderTexturedStacked;
     case WWT::HSVWaveform:
     case WWT::QtHSVWaveform:
         return WWT::AllShaderHSVWaveform;
@@ -471,8 +478,10 @@ UserSettingsPointer Upgrade::versionUpgrade(const QString& settingsPath) {
                     // Sandbox isn't setup yet at this point in startup because it relies on
                     // the config settings path and this function is what loads the config
                     // so it's not ready yet.
-                    successful = tc.addDirectory(mixxx::FileInfo(currentFolder));
-
+                    successful =
+                            tc.addDirectory(mixxx::FileInfo(currentFolder)) ==
+                            DirectoryDAO::AddResult::Ok;
+                    ;
                     tc.disconnectDatabase();
                 }
             }
