@@ -1,8 +1,8 @@
 #pragma once
 #include <QColor>
 #include <QObject>
+#include <QQmlEngine>
 #include <QVariantList>
-#include <QtQml>
 
 #include "preferences/usersettings.h"
 
@@ -18,14 +18,20 @@ class QmlConfigProxy : public QObject {
             UserSettingsPointer pConfig,
             QObject* parent = nullptr);
 
+    // We use method here instead of properties as there is no way to achieve property binding
+    // with UserSettings, since there is no synchronisation upon mutations.
     Q_INVOKABLE QVariantList getHotcueColorPalette();
     Q_INVOKABLE QVariantList getTrackColorPalette();
+    Q_INVOKABLE int getMultiSamplingLevel();
 
     static QmlConfigProxy* create(QQmlEngine* pQmlEngine, QJSEngine* pJsEngine);
-    static inline QmlConfigProxy* s_pInstance = nullptr;
+    static inline void registerUserSettings(UserSettingsPointer pConfig) {
+        s_pUserSettings = std::move(pConfig);
+    }
 
   private:
-    static inline QJSEngine* s_pJsEngine = nullptr;
+    static inline UserSettingsPointer s_pUserSettings = nullptr;
+
     const UserSettingsPointer m_pConfig;
 };
 
