@@ -16,30 +16,17 @@ QmlLibraryProxy::QmlLibraryProxy(std::shared_ptr<Library> pLibrary, QObject* par
 
 // static
 QmlLibraryProxy* QmlLibraryProxy::create(QQmlEngine* pQmlEngine, QJSEngine* pJsEngine) {
-    Q_UNUSED(pQmlEngine);
-
     // The implementation of this method is mostly taken from the code example
     // that shows the replacement for `qmlRegisterSingletonInstance()` when
     // using `QML_SINGLETON`.
     // https://doc.qt.io/qt-6/qqmlengine.html#QML_SINGLETON
 
     // The instance has to exist before it is used. We cannot replace it.
-    DEBUG_ASSERT(s_pInstance);
-
-    // The engine has to have the same thread affinity as the singleton.
-    DEBUG_ASSERT(pJsEngine->thread() == s_pInstance->thread());
-
-    // There can only be one engine accessing the singleton.
-    if (s_pJsEngine) {
-        DEBUG_ASSERT(pJsEngine == s_pJsEngine);
-    } else {
-        s_pJsEngine = pJsEngine;
+    VERIFY_OR_DEBUG_ASSERT(s_pLibrary) {
+        qWarning() << "Library hasn't been registered yet";
+        return nullptr;
     }
-
-    // Explicitly specify C++ ownership so that the engine doesn't delete
-    // the instance.
-    QJSEngine::setObjectOwnership(s_pInstance, QJSEngine::CppOwnership);
-    return s_pInstance;
+    return new QmlLibraryProxy(s_pLibrary, pQmlEngine);
 }
 
 } // namespace qml
