@@ -1,17 +1,15 @@
 #pragma once
 
-#include <QString>
 #include <QList>
+#include <QString>
 
-#include "util/types.h"
+#include "audio/types.h"
 #include "preferences/usersettings.h"
-#include "soundio/sounddeviceerror.h"
+#include "soundio/sounddevicestatus.h"
 #include "soundio/soundmanagerutil.h"
+#include "util/types.h"
 
-class SoundDevice;
 class SoundManager;
-class AudioOutput;
-class AudioInput;
 class AudioOutputBuffer;
 class AudioInputBuffer;
 
@@ -31,19 +29,19 @@ class SoundDevice {
     inline const QString& getHostAPI() const {
         return m_hostAPI;
     }
-    void setSampleRate(double sampleRate);
+    void setSampleRate(mixxx::audio::SampleRate sampleRate);
     void setConfigFramesPerBuffer(unsigned int framesPerBuffer);
-    virtual SoundDeviceError open(bool isClkRefDevice, int syncBuffers) = 0;
+    virtual SoundDeviceStatus open(bool isClkRefDevice, int syncBuffers) = 0;
     virtual bool isOpen() const = 0;
-    virtual SoundDeviceError close() = 0;
+    virtual SoundDeviceStatus close() = 0;
     virtual void readProcess(SINT framesPerBuffer) = 0;
     virtual void writeProcess(SINT framesPerBuffer) = 0;
     virtual QString getError() const = 0;
-    virtual unsigned int getDefaultSampleRate() const = 0;
-    int getNumOutputChannels() const;
-    int getNumInputChannels() const;
-    SoundDeviceError addOutput(const AudioOutputBuffer& out);
-    SoundDeviceError addInput(const AudioInputBuffer& in);
+    virtual mixxx::audio::SampleRate getDefaultSampleRate() const = 0;
+    mixxx::audio::ChannelCount getNumOutputChannels() const;
+    mixxx::audio::ChannelCount getNumInputChannels() const;
+    SoundDeviceStatus addOutput(const AudioOutputBuffer& out);
+    SoundDeviceStatus addInput(const AudioInputBuffer& in);
     const QList<AudioInputBuffer>& inputs() const {
         return m_audioInputs;
     }
@@ -77,11 +75,11 @@ class SoundDevice {
     // The name of the soundcard, as displayed to the user
     QString m_strDisplayName;
     // The number of output channels that the soundcard has
-    int m_iNumOutputChannels;
+    mixxx::audio::ChannelCount m_numOutputChannels;
     // The number of input channels that the soundcard has
-    int m_iNumInputChannels;
+    mixxx::audio::ChannelCount m_numInputChannels;
     // The current samplerate for the sound device.
-    double m_dSampleRate;
+    mixxx::audio::SampleRate m_sampleRate;
     // The name of the audio API used by this device.
     QString m_hostAPI;
     // The **configured** number of frames per buffer. We'll tell PortAudio we
