@@ -1,4 +1,6 @@
+#ifdef USE_BENCH
 #include <benchmark/benchmark.h>
+#endif
 
 #include "errordialoghandler.h"
 #include "mixxxtest.h"
@@ -8,6 +10,7 @@ int main(int argc, char **argv) {
     // We never want to popup error dialogs when running tests.
     ErrorDialogHandler::setEnabled(false);
 
+#ifdef USE_BENCH
     bool run_benchmarks = false;
     for (int i = 0; i < argc; ++i) {
         if (strcmp(argv[i], "--benchmark") == 0) {
@@ -33,4 +36,9 @@ int main(int argc, char **argv) {
     } else {
         return RUN_ALL_TESTS();
     }
+#else
+    testing::InitGoogleTest(&argc, argv);
+    MixxxTest::ApplicationScope applicationScope(argc, argv);
+    return RUN_ALL_TESTS();
+#endif
 }
