@@ -321,46 +321,63 @@ mixxx::Bpm BeatUtils::makeConstBpm(
     return roundBpm;
 }
 
+// static
+std::optional<mixxx::Bpm> BeatUtils::trySnap(mixxx::Bpm minBpm,
+        mixxx::Bpm centerBpm,
+        mixxx::Bpm maxBpm,
+        double fraction) {
+    mixxx::Bpm snapBpm = mixxx::Bpm(round(centerBpm.value() * fraction) / fraction);
+    if (snapBpm > minBpm && snapBpm < maxBpm) {
+        return snapBpm;
+    }
+    return std::nullopt;
+};
+
 // static
 mixxx::Bpm BeatUtils::roundBpmWithinRange(
         mixxx::Bpm minBpm, mixxx::Bpm centerBpm, mixxx::Bpm maxBpm) {
     // First try to snap to a full integer BPM
     // FIXME: calling bpm.value() without checking bpm.isValid()
-    auto snapBpm = mixxx::Bpm(round(centerBpm.value()));
-    if (snapBpm > minBpm && snapBpm < maxBpm) {
-        // Success
-        return snapBpm;
+    std::optional<mixxx::Bpm> snapBpm = trySnap(minBpm, centerBpm, maxBpm, 1.0);
+    if (snapBpm) {
+        return *snapBpm;
     }
 
-    // Probe the reasonable multipliers for 0.5
-    const double roundBpmWidth = maxBpm - minBpm;
-    if (roundBpmWidth > 0.5) {
-        // 0.5 BPM are only reasonable if the double value is not insane
-        // or the 2/3 value is not too small.
-        if (centerBpm < mixxx::Bpm(85.0)) {
-            // this cane be actually up to 175 BPM
-            // allow halve BPM values
-            return mixxx::Bpm(round(centerBpm.value() * 2) / 2);
-        } else if (centerBpm > mixxx::Bpm(127.0)) {
-            // optimize for 2/3 going down to 85
-            return mixxx::Bpm(round(centerBpm.value() / 3 * 2) * 3 / 2);
+    // 0.5 BPM are only reasonable if the double value is not insane
+    // else other factors below are more typical
+    if (centerBpm < mixxx::Bpm(85.0)) {
+        // this can be actually up to 175 BPM
+        // allow halve BPM values
+        snapBpm = trySnap(minBpm, centerBpm, maxBpm, 2.0);
+        if (snapBpm) {
+            return *snapBpm;
         }
     }
 
-    if (roundBpmWidth > 1.0 / 12) {
-        // this covers all sorts of 1/2 2/3 and 3/4 multiplier
-        return mixxx::Bpm(round(centerBpm.value() * 12) / 12);
-    } else {
-        // We are here if we have more that ~75 beats and ~30 s
-        // try to snap to a 1/12 Bpm
-        snapBpm = mixxx::Bpm(round(centerBpm.value() * 12) / 12);
-        if (snapBpm > minBpm && snapBpm < maxBpm) {
-            // Success
-            return snapBpm;
+    if (centerBpm > mixxx::Bpm(127.0)) {
+        // optimize for 2/3 going down to 85
+        // else other factors below are more typical
+        snapBpm = trySnap(minBpm, centerBpm, maxBpm, 2.0 / 3.0);
+        if (snapBpm) {
+            return *snapBpm;
         }
-        // else give up and use the original BPM value.
     }
 
+    // try to snap to a 1/3 Bpm
+    // This covers all sorts of 3/2 and 3/4 multipliers
+    snapBpm = trySnap(minBpm, centerBpm, maxBpm, 3.0);
+    if (snapBpm) {
+        return *snapBpm;
+    }
+
+    // try to snap to a 1/12 Bpm
+    // This covers all other sorts of typical multipliers
+    snapBpm = trySnap(minBpm, centerBpm, maxBpm, 12.0);
+    if (snapBpm) {
+        return *snapBpm;
+    }
+
+    // else give up and use the original BPM value.
     return centerBpm;
 }
 
