@@ -1,5 +1,6 @@
 #pragma once
 
+#include <QUrl>
 #include <QtGlobal>
 
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
@@ -11,6 +12,8 @@ namespace mixxx {
 class DesktopHelper {
 public:
    static void openInFileBrowser(const QStringList& paths);
+
+   static bool openUrl(const QUrl& url);
 };
 
 } // namespace mixxx
