@@ -10,18 +10,6 @@
 #include <cmath>
 #include <limits>
 
-int util_fpclassify(float x) {
-    return std::fpclassify(x);
-}
-
-bool util_isfinite(float x) {
-    return std::isfinite(x);
-}
-
-bool util_isnormal(float x) {
-    return std::isnormal(x);
-}
-
 int util_isnan(float x) {
     return std::isnan(x);
 }
@@ -30,10 +18,6 @@ int util_isinf(float x) {
     return std::isinf(x);
 }
 
-int util_fpclassify(double x) {
-    return std::fpclassify(x);
-}
-
 bool util_isfinite(double x) {
     return std::isfinite(x);
 }
@@ -57,3 +41,11 @@ float util_float_infinity() {
 double util_double_infinity() {
     return std::numeric_limits<double>::infinity();
 }
+
+float util_float_nan() {
+    return std::numeric_limits<double>::quiet_NaN();
+}
+
+double util_double_nan() {
+    return std::numeric_limits<double>::quiet_NaN();
+}
