@@ -1,14 +1,6 @@
 #pragma once
 
-#if __has_include(<span>)
 #include <span>
-#else
-#include <gsl/span>
-namespace std {
-using gsl::span;
-} // namespace std
-#endif
-
 #include <type_traits>
 
 #include "util/assert.h"
@@ -21,7 +13,7 @@ namespace spanutil {
 /// At the same time, the function provides appropriate lower bound checking
 /// for signed data types.
 template<typename T, typename S, typename T2 = typename std::span<T>::size_type>
-constexpr T2 castToSizeType(S size) {
+constexpr T2 castToSizeType(S size) noexcept {
     if constexpr (std::is_signed_v<S> && std::is_unsigned_v<T2>) {
         VERIFY_OR_DEBUG_ASSERT(size >= 0) {
             size = 0;
@@ -35,7 +27,7 @@ constexpr T2 castToSizeType(S size) {
 /// In most cases, the pointer to the raw data of a data structure
 /// is used, and the size of the data structure.
 template<typename T, typename S>
-constexpr std::span<T> spanFromPtrLen(T* ptr, S size) {
+constexpr std::span<T> spanFromPtrLen(T* ptr, S size) noexcept {
     return std::span<T>{ptr, mixxx::spanutil::castToSizeType<T>(size)};
 }
 
