@@ -1,10 +1,10 @@
 #pragma once
 #include <QDomNode>
 #include <QImage>
+#include <memory>
 
 #include "control/controlproxy.h"
 #include "track/cue.h"
-#include "util/memory.h"
 #include "waveform/waveformmarklabel.h"
 
 class SkinContext;
@@ -63,10 +63,17 @@ class WaveformMark {
         return m_pPositionCO->get();
     }
     double getSampleEndPosition() const {
-        if (m_pEndPositionCO) {
-            return m_pEndPositionCO->get();
+        if (!m_pEndPositionCO ||
+                // A hotcue may have an end position although it isn't a saved
+                // loop anymore. This happens when the user changes the cue
+                // type. However, we persist the end position if the user wants
+                // to restore the cue to a saved loop
+                (m_pTypeCO &&
+                        static_cast<mixxx::CueType>(m_pTypeCO->get()) !=
+                                mixxx::CueType::Loop)) {
+            return Cue::kNoPosition;
         }
-        return Cue::kNoPosition;
+        return m_pEndPositionCO->get();
     }
     QString getItem() const {
         return m_pPositionCO->getKey().item;
@@ -82,6 +89,9 @@ class WaveformMark {
         }
         return m_pVisibleCO->toBool();
     }
+    bool isShowUntilNext() const {
+        return m_showUntilNext;
+    }
 
     template<typename Receiver, typename Slot>
     void connectVisibleChanged(Receiver receiver, Slot slot) const {
@@ -160,6 +170,7 @@ class WaveformMark {
   private:
     std::unique_ptr<ControlProxy> m_pPositionCO;
     std::unique_ptr<ControlProxy> m_pEndPositionCO;
+    std::unique_ptr<ControlProxy> m_pTypeCO;
     std::unique_ptr<ControlProxy> m_pVisibleCO;
 
     std::unique_ptr<Graphics> m_pGraphics;
@@ -167,6 +178,9 @@ class WaveformMark {
     int m_iPriority;
     int m_iHotCue;
 
+    // Whether this marker is used in the show beats/time until next marker display.
+    bool m_showUntilNext;
+
     QColor m_fillColor;
     QColor m_borderColor;
     QColor m_labelColor;
