@@ -1,15 +1,19 @@
 #include "waveform/sharedglcontext.h"
 
-#include <QtDebug>
+#ifndef MIXXX_USE_QOPENGL
+#include <QDebug>
 #include <QGLContext>
 #include <QGLFormat>
-#include <QGLWidget>
 
-QGLWidget* SharedGLContext::s_pSharedGLWidget = nullptr;
+#include "widget/wglwidget.h"
+#endif
+
+WGLWidget* SharedGLContext::s_pSharedGLWidget = nullptr;
 
 // static
-void SharedGLContext::setWidget(QGLWidget* pWidget) {
+void SharedGLContext::setWidget(WGLWidget* pWidget) {
     s_pSharedGLWidget = pWidget;
+#ifndef MIXXX_USE_QOPENGL
     qDebug() << "Set root GL Context widget valid:"
              << pWidget << (pWidget && pWidget->isValid());
     if (pWidget) {
@@ -29,9 +33,10 @@ void SharedGLContext::setWidget(QGLWidget* pWidget) {
         qDebug() << "Stencil buffers:" << format.stencil();
         qDebug() << "Stereo:" << format.stereo();
     }
+#endif
 }
 
 // static
-QGLWidget* SharedGLContext::getWidget() {
+WGLWidget* SharedGLContext::getWidget() {
     return s_pSharedGLWidget;
 }
