@@ -2,12 +2,12 @@
 
 #include <QColor>
 #include <QFont>
-#include <QFontMetrics>
-#include <QPainter>
 #include <QPixmap>
 #include <QString>
 #include <QRectF>
 
+class QPainter;
+
 // WaveformMarkLabel renders the label for a WaveformMark to an offscreen buffer
 // and calculates its area. This allows the areas of all WaveformMarkLabels
 // to be compared so overlapping labels are not drawn.
