@@ -14,6 +14,9 @@ class QtVSyncTestWidget : public GLWaveformWidgetAbstract {
     static inline bool useOpenGl() { return true; }
     static inline bool useOpenGles() { return true; }
     static inline bool useOpenGLShaders() { return false; }
+    static inline bool useTextureForWaveform() {
+        return false;
+    }
     static inline WaveformWidgetCategory category() {
         return WaveformWidgetCategory::DeveloperOnly;
     }
