@@ -2,6 +2,10 @@
 
 #include "moc_hexspinbox.cpp"
 
+namespace {
+const QRegularExpression kValidationRegex(QStringLiteral("^0(x|X)[0-9A-Fa-f]+"));
+} // namespace
+
 HexSpinBox::HexSpinBox(QWidget* pParent)
         : QSpinBox(pParent) {
     setRange(0, 255);
@@ -19,7 +23,6 @@ int HexSpinBox::valueFromText(const QString& text) const {
 }
 
 QValidator::State HexSpinBox::validate(QString& input, int& pos) const {
-    const QRegExp regExp("^0(x|X)[0-9A-Fa-f]+");
-    QRegExpValidator validator(regExp, nullptr);
+    QRegularExpressionValidator validator(kValidationRegex, nullptr);
     return validator.validate(input, pos);
 }
