@@ -1,16 +1,15 @@
 #pragma once
 
-#include <QWidget>
-
 #include "preferences/usersettings.h"
 #include "widget/wtracktableview.h"
 
 class WAnalysisLibraryTableView : public WTrackTableView {
+    Q_OBJECT
   public:
     WAnalysisLibraryTableView(
             QWidget* parent,
             UserSettingsPointer pConfig,
-            TrackCollectionManager* pTrackCollectionManager,
+            Library* pLibrary,
             double trackTableBackgroundColorOpacity);
 
     void onSearch(const QString& text) override;
