@@ -1,5 +1,7 @@
 #pragma once
 
+#include <optional>
+
 #include "skin/legacy/skincontext.h"
 #include "widget/knobeventhandler.h"
 #include "widget/wpixmapstore.h"
@@ -26,8 +28,12 @@ class WKnobComposed : public WWidget {
     void mousePressEvent(QMouseEvent *e) override;
     void mouseDoubleClickEvent(QMouseEvent* e) override;
     void mouseReleaseEvent(QMouseEvent *e) override;
+    void resizeEvent(QResizeEvent* /*unused*/) override;
     void paintEvent(QPaintEvent* /*unused*/) override;
 
+    std::optional<double> m_defaultAngle;
+    void setDefaultAngleFromParameterOrReset(std::optional<double> parameter);
+
   private:
     void inputActivity();
     void clear();
@@ -41,10 +47,10 @@ class WKnobComposed : public WWidget {
             double scaleFactor);
     void drawArc(QPainter* pPainter);
 
-    double m_dCurrentAngle;
     PaintablePointer m_pKnob;
     PaintablePointer m_pPixmapBack;
     KnobEventHandler<WKnobComposed> m_handler;
+    double m_dCurrentAngle;
     double m_dMinAngle;
     double m_dMaxAngle;
     double m_dKnobCenterXOffset;
@@ -57,6 +63,7 @@ class WKnobComposed : public WWidget {
     bool m_arcUnipolar;
     bool m_arcReversed;
     Qt::PenCapStyle m_arcPenCap;
+    QRectF m_rect;
 
     friend class KnobEventHandler<WKnobComposed>;
 };
