@@ -1,18 +1,15 @@
 #pragma once
 
 #include <QBasicTimer>
-#include <QContextMenuEvent>
-#include <QDragEnterEvent>
-#include <QDragMoveEvent>
-#include <QKeyEvent>
 #include <QModelIndex>
-#include <QPoint>
-#include <QTimerEvent>
 #include <QTreeView>
-#include <QEvent>
 
+#include "library/library_decl.h"
 #include "widget/wbasewidget.h"
 
+class LibraryFeature;
+class QPoint;
+
 class WLibrarySidebar : public QTreeView, public WBaseWidget {
     Q_OBJECT
   public:
@@ -23,21 +20,32 @@ class WLibrarySidebar : public QTreeView, public WBaseWidget {
     void dragEnterEvent(QDragEnterEvent * event) override;
     void dropEvent(QDropEvent * event) override;
     void keyPressEvent(QKeyEvent* event) override;
+    void mousePressEvent(QMouseEvent* event) override;
+    void focusInEvent(QFocusEvent* event) override;
     void timerEvent(QTimerEvent* event) override;
     void toggleSelectedItem();
     bool isLeafNodeSelected();
+    bool isChildIndexSelected(const QModelIndex& index);
+    bool isFeatureRootIndexSelected(LibraryFeature* pFeature);
 
   public slots:
     void selectIndex(const QModelIndex&);
+    void selectChildIndex(const QModelIndex&, bool selectItem = true);
     void slotSetFont(const QFont& font);
 
   signals:
     void rightClicked(const QPoint&, const QModelIndex&);
+    void renameItem(const QModelIndex&);
+    void deleteItem(const QModelIndex&);
+    FocusWidget setLibraryFocus(FocusWidget newFocus);
 
   protected:
     bool event(QEvent* pEvent) override;
 
   private:
+    void focusSelectedIndex();
+    QModelIndex selectedIndex();
+
     QBasicTimer m_expandTimer;
     QModelIndex m_hoverIndex;
 };
