@@ -4,6 +4,7 @@
 #include <QString>
 #include <QTableView>
 
+#include "library/library_decl.h"
 #include "library/libraryview.h"
 #include "preferences/usersettings.h"
 #include "track/track_decl.h"
@@ -25,8 +26,6 @@ class WLibraryTableView : public QTableView, public virtual LibraryView {
             UserSettingsPointer pConfig);
     ~WLibraryTableView() override;
 
-    void moveSelection(int delta) override;
-
     /// @brief saveTrackModelState function saves current positions of scrollbars,
     /// current item selection and current index in a QCache using a unique
     /// string key - can be any value but should invariant for model
@@ -61,6 +60,7 @@ class WLibraryTableView : public QTableView, public virtual LibraryView {
     void trackSelected(TrackPointer pTrack);
     void onlyCachedCoverArt(bool);
     void scrollValueChanged(int);
+    FocusWidget setLibraryFocus(FocusWidget newFocus);
 
   public slots:
     void setTrackTableFont(const QFont& font);
