@@ -36,6 +36,10 @@ class WMainMenuBar : public QMenuBar {
   public:
     WMainMenuBar(QWidget* pParent, UserSettingsPointer pConfig,
                  ConfigObject<ConfigValueKbd>* pKbdConfig);
+#ifndef __APPLE__
+    void hideMenuBar();
+    void showMenuBar();
+#endif
 
   public slots:
     void onLibraryScanStarted();
@@ -50,6 +54,9 @@ class WMainMenuBar : public QMenuBar {
     void onVinylControlDeckEnabledStateChange(int deck, bool enabled);
     void onNumberOfDecksChanged(int decks);
     void onKeywheelChange(int state);
+#ifndef __APPLE__
+    void slotToggleMenuBar();
+#endif
 
   signals:
     void createCrate();
@@ -60,6 +67,7 @@ class WMainMenuBar : public QMenuBar {
 #ifdef __ENGINEPRIME__
     void exportLibrary();
 #endif
+    void menubarAutoHideChanged(bool autohide);
     void showAbout();
     void showKeywheel(bool visible);
     void showPreferences();
@@ -82,6 +90,9 @@ class WMainMenuBar : public QMenuBar {
     void internalOnNewSkinAboutToLoad();
 
   private slots:
+#ifndef __APPLE__
+    void slotAutoHideMenuBarToggled(bool autoHide);
+#endif
     void slotDeveloperStatsExperiment(bool enable);
     void slotDeveloperStatsBase(bool enable);
     void slotDeveloperDebugger(bool toggle);
@@ -89,6 +100,11 @@ class WMainMenuBar : public QMenuBar {
 
   private:
     void initialize();
+#ifndef __APPLE__
+    /// this ensures the menubar is shown when a menu hotkey is pressed
+    /// while the menubar is hidden
+    void connectMenuToSlotShowMenuBar(const QMenu* pMenu);
+#endif
     void createVisibilityControl(QAction* pAction, const ConfigKey& key);
 
     UserSettingsPointer m_pConfig;
