@@ -186,22 +186,23 @@ void WTrackTableView::pasteFromSidebar() {
 }
 
 // slot
-void WTrackTableView::loadTrackModel(QAbstractItemModel* model, bool restoreState) {
-    qDebug() << "WTrackTableView::loadTrackModel()" << model;
+void WTrackTableView::loadTrackModel(QAbstractItemModel* pNewModel, bool restoreState) {
+    qDebug() << "WTrackTableView::loadTrackModel()" << pNewModel;
 
-    VERIFY_OR_DEBUG_ASSERT(model) {
+    VERIFY_OR_DEBUG_ASSERT(pNewModel) {
         return;
     }
-    TrackModel* pTrackModel = dynamic_cast<TrackModel*>(model);
-    VERIFY_OR_DEBUG_ASSERT(pTrackModel) {
+    TrackModel* pNewTrackModel = dynamic_cast<TrackModel*>(pNewModel);
+    VERIFY_OR_DEBUG_ASSERT(pNewTrackModel) {
         return;
     }
 
-    m_sorting = pTrackModel->hasCapabilities(TrackModel::Capability::Sorting);
+    m_sorting = pNewTrackModel->hasCapabilities(TrackModel::Capability::Sorting);
 
     // If the model has not changed there's no need to exchange the headers
     // which would cause a small GUI freeze
-    if (getTrackModel() == pTrackModel) {
+    TrackModel* pCurrModel = getTrackModel();
+    if (pCurrModel == pNewTrackModel) {
         // Re-sort the table even if the track model is the same. This triggers
         // a select() if the table is dirty.
         doSortByColumn(horizontalHeader()->sortIndicatorSection(),
@@ -211,6 +212,8 @@ void WTrackTableView::loadTrackModel(QAbstractItemModel* model, bool restoreStat
             restoreCurrentViewState();
         }
         return;
+    } else if (pCurrModel) {
+        pCurrModel->maybeStopModelPopulation();
     }
 
     setVisible(false);
@@ -252,7 +255,7 @@ void WTrackTableView::loadTrackModel(QAbstractItemModel* model, bool restoreStat
     setSortingEnabled(false);
     setHorizontalHeader(tempHeader);
 
-    setModel(model);
+    setModel(pNewModel);
     setHorizontalHeader(header);
     header->setSectionsMovable(true);
     header->setSectionsClickable(true);
@@ -266,10 +269,10 @@ void WTrackTableView::loadTrackModel(QAbstractItemModel* model, bool restoreStat
     header->setDefaultAlignment(Qt::AlignLeft);
 
     // Initialize all column-specific things
-    for (int i = 0; i < model->columnCount(); ++i) {
+    for (int i = 0; i < pNewModel->columnCount(); ++i) {
         // Setup delegates according to what the model tells us
         QAbstractItemDelegate* delegate =
-                pTrackModel->delegateForColumn(i, this);
+                pNewTrackModel->delegateForColumn(i, this);
         // We need to delete the old delegates, since the docs say the view will
         // not take ownership of them.
         QAbstractItemDelegate* old_delegate = itemDelegateForColumn(i);
@@ -278,7 +281,7 @@ void WTrackTableView::loadTrackModel(QAbstractItemModel* model, bool restoreStat
         delete old_delegate;
 
         // Show or hide the column based on whether it should be shown or not.
-        if (pTrackModel->isColumnInternal(i)) {
+        if (pNewTrackModel->isColumnInternal(i)) {
             //qDebug() << "Hiding column" << i;
             horizontalHeader()->hideSection(i);
         }
@@ -286,7 +289,7 @@ void WTrackTableView::loadTrackModel(QAbstractItemModel* model, bool restoreStat
         // due to database schema evolution we gonna hide all columns that may
         // contain a potential large number of NULL values.  This will hide the
         // key column by default unless the user brings it to front
-        if (pTrackModel->isColumnHiddenByDefault(i) &&
+        if (pNewTrackModel->isColumnHiddenByDefault(i) &&
                 !header->hasPersistedHeaderState()) {
             //qDebug() << "Hiding column" << i;
             horizontalHeader()->hideSection(i);
@@ -306,22 +309,24 @@ void WTrackTableView::loadTrackModel(QAbstractItemModel* model, bool restoreStat
 
         Qt::SortOrder sortOrder;
         TrackModel::SortColumnId sortColumn =
-                pTrackModel->sortColumnIdFromColumnIndex(
+                pNewTrackModel->sortColumnIdFromColumnIndex(
                         horizontalHeader()->sortIndicatorSection());
         if (sortColumn != TrackModel::SortColumnId::Invalid) {
             // Sort by the saved sort section and order.
             sortOrder = horizontalHeader()->sortIndicatorOrder();
         } else {
             // No saved order is present. Use the TrackModel's default sort order.
-            sortColumn = pTrackModel->sortColumnIdFromColumnIndex(pTrackModel->defaultSortColumn());
-            sortOrder = pTrackModel->defaultSortOrder();
+            sortColumn = pNewTrackModel->sortColumnIdFromColumnIndex(
+                    pNewTrackModel->defaultSortColumn());
+            sortOrder = pNewTrackModel->defaultSortOrder();
 
             if (sortColumn == TrackModel::SortColumnId::Invalid) {
                 // If the TrackModel has an invalid or internal column as its default
                 // sort, find the first valid sort column and sort by that.
-                const int columnCount = model->columnCount(); // just to avoid an endless while loop
+                // avoid endless while loop
+                const int columnCount = pNewModel->columnCount();
                 for (int sortColumnIndex = 0; sortColumnIndex < columnCount; sortColumnIndex++) {
-                    sortColumn = pTrackModel->sortColumnIdFromColumnIndex(sortColumnIndex);
+                    sortColumn = pNewTrackModel->sortColumnIdFromColumnIndex(sortColumnIndex);
                     if (sortColumn != TrackModel::SortColumnId::Invalid) {
                         break;
                     }
@@ -344,7 +349,7 @@ void WTrackTableView::loadTrackModel(QAbstractItemModel* model, bool restoreStat
     // this.)
     setDragEnabled(true);
 
-    if (pTrackModel->hasCapabilities(TrackModel::Capability::ReceiveDrops)) {
+    if (pNewTrackModel->hasCapabilities(TrackModel::Capability::ReceiveDrops)) {
         setDragDropMode(QAbstractItemView::DragDrop);
         setDropIndicatorShown(true);
         setAcceptDrops(true);
@@ -1103,29 +1108,32 @@ void WTrackTableView::moveSelectedTracks(QKeyEvent* event) {
         return;
     }
 
-    int destRow = 0;
-    if (top) {
-        destRow = 0;
-    } else if (bottom || ((bottom || down || pageDown) && lastSelRow == rowCount - 1)) {
-        // In case of End or non-continuous and lastSelRow already at the end
-        // we simply paste at the end by invalidating the index.
+    int destRow = 0; // for Home (top)
+    if (bottom || ((down || pageDown) && lastSelRow == rowCount - 1)) {
+        // In case of End, or non-continuous selection and lastSelRow already
+        // at the end, we simply paste at the end by invalidating the index.
         destRow = -1;
     } else if (up || pageUp) {
         // currentIndex can be anywhere inside or outside the selection.
-        // Set it top or bottom of the selection, then pass through the key event
+        // Set it to first selected row, then pass through the key event
         // to get us the desired destination index.
         setCurrentIndex(model()->index(firstSelRow, currentIndex().column()));
         QTableView::keyPressEvent(event);
         destRow = currentIndex().row();
-    } else {
-        // Same when moving down.
+        if (destRow >= lastSelRow) {
+            // Multiple Up presses caused moveCursor() to wrap around.
+            // Paste at the top.
+            destRow = 0;
+        }
+    } else if (down || pageDown) {
+        // Same when moving down, set index to last selected row.
         setCurrentIndex(model()->index(lastSelRow, currentIndex().column()));
         QTableView::keyPressEvent(event);
         destRow = currentIndex().row() + 1;
-        if (pageDown && destRow >= rowCount) {
-            // PageDown hit the end of the list. Explicitly paste at the
+        if ((pageDown && destRow >= rowCount) || destRow <= firstSelRow) {
+            // PageDown hit the end of the list, or moveCursor() wrapped around.
+            // Explicitly paste at the end.
             destRow = -1;
-        } else {
         }
     }
 
